/*                                                                             
 * Copyright 2005,2006 WSO2, Inc. http://www.wso2.org
 *                                                                             
 * Licensed under the Apache License, Version 2.0 (the "License");             
 * you may not use this file except in compliance with the License.            
 * You may obtain a copy of the License at                                     
 *                                                                             
 *      http://www.apache.org/licenses/LICENSE-2.0                             
 *                                                                             
 * Unless required by applicable law or agreed to in writing, software         
 * distributed under the License is distributed on an "AS IS" BASIS,           
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.    
 * See the License for the specific language governing permissions and         
 * limitations under the License.                                              
 */
package org.wso2.solutions.identity;

/**
 * Constants of the identity provider
 */
public class IdentityProviderConstants {

    private IdentityProviderConstants() {
    }

    public final static String RESOURCES = "org.wso2.solutions.identity.resources";

    public final static String INITIAL_CLAIMS_FILE_PATH = "conf/initial-claims.xml";

    public static final String PROPERTY_USER = "IdentityProvier.User";

    // Attibute namespaces
    public final static String ATTR_NS_GIVEN_NAME = IdentityConstants.NS
            + "/claims/givenname";

    public final static String ATTR_NS_SURNAME = IdentityConstants.NS
            + "/claims/surname";

    public final static String ATTR_NS_EMAIL_ADDRESS = IdentityConstants.NS
            + "/claims/emailaddress";

    public final static String ATTR_NS_STREET_ADDRESS = IdentityConstants.NS
            + "/claims/streetaddress";

    public final static String ATTR_NS_CITY = IdentityConstants.NS
            + "/claims/locality";

    public final static String ATTR_NS_STATE = IdentityConstants.NS
            + "/claims/stateorprovince";

    public final static String ATTR_NS_POSTAL_CODE = IdentityConstants.NS
            + "/claims/postalcode";

    public final static String ATTR_NS_COUNTRY = IdentityConstants.NS
            + "/claims/country";

    public final static String ATTR_NS_HOME_PHONE = IdentityConstants.NS
            + "/claims/homephone";

    public final static String ATTR_NS_WORK_PHONE = IdentityConstants.NS
            + "/claims/otherphone";

    public final static String ATTR_NS_MOBILE_PHONE = IdentityConstants.NS
            + "/claims/mobile";

    // Attibute namespaces
    public final static String DISPLAY_GIVEN_NAME = "Given Name";

    public final static String DISPLAY_SURNAME = "Surname";

    public final static String DISPLAY_EMAIL_ADDRESS = "Email address";

    public final static String DISPLAY_STREET_ADDRESS = "Street address";

    public final static String DISPLAY_CITY = "City";

    public final static String DISPLAY_STATE = "State or Province";

    public final static String DISPLAY_POSTAL_CODE = "Postal code";

    public final static String DISPLAY_COUNTRY = "Country";

    public final static String DISPLAY_HOME_PHONE = "Homephone(Primary)";

    public final static String DISPLAY_WORK_PHONE = "Otherphone";

    public final static String DISPLAY_MOBILE_PHONE = "Mobile";

    public final static String ISSUER_SELF = "Self";

    /**
     * Local names of the identity provider constants
     */
    public static class LocalNames {
        public static final String REQUESTED_DISPLAY_TOKEN = "RequestedDisplayToken";

        public static final String REQUEST_DISPLAY_TOKEN = "RequestDisplayToken";

        public static final String DISPLAY_TOKEN = "DisplayToken";

        public static final String DISPLAY_CLAIM = "DisplayClaim";

        public static final String DISPLAY_TAG = "DisplayTag";

        public static final String DISPLAY_VALUE = "DisplayValue";

        public static final String IDENTITY_CLAIM = "Claim";

        public static final String IDENTITY_CLAIM_TYPE = "ClaimType";

        public static final String INFO_CARD_REFERENCE = "InformationCardReference";

        public static final String CARD_ID = "CardId";

        public final static String SELFISSUED_AUTHENTICATE = "SelfIssuedAuthenticate";

        public final static String USERNAME_PASSWORD_AUTHENTICATE = "UserNamePasswordAuthenticate";

        public final static String KEBEROSV5_AUTHENTICATE = "KerberosV5Authenticate";

        public final static String X509V3_AUTNENTICATE = "X509V3Authenticate";

    }

    public static final String SERVICE_NAME_STS_UT = "sts-ut";

    public static final String SERVICE_NAME_STS_UT_SYMM = "sts-ut-symm";

    public static final String SERVICE_NAME_STS_IC = "sts-ic";

    public static final String SERVICE_NAME_STS_IC_SYMM = "sts-ic-symm";

    public static final String SERVICE_NAME_MEX_UT = "mex-ut";

    public static final String SERVICE_NAME_MEX_UT_SYMM = "mex-ut-symm";

    public static final String SERVICE_NAME_MEX_IC = "mex-ic";

    public static final String SERVICE_NAME_MEX_IC_SYMM = "mex-ic-symm";

    // auth mechanism
    public static final int AUTH_TYPE_USERNAME_TOKEN = 1;

    public static final int AUTH_TYPE_KEBEROS_TICKET = 2;

    public static final int AUTH_TYPE_X509_CERTIFICATE = 3;

    public static final int AUTH_TYPE_SELF_ISSUED = 4;
    
    public static final String RP_USER_ROLE = "Rp_User_Role";

    /**
     * Sample related constants of the identity provider
     */
    public static class Sample {
        public final static String CONNECTION_URL = "jdbc:derby:../database/WSO2IDENTITY_SAMPLE_DB";

        public final static String CONNECTION_USER_NAME = "wso2is";

        public final static String CONNECTION_PASSWORD = "wso2is";

        public final static String DRIVER = "org.apache.derby.jdbc.EmbeddedDriver";

        public final static String USER_TABLE = "sample_user";

        public final static String USER_NAME_COLUMN = "USERNAME";

        public final static String PASSWORD_COLUMN = "PASSWORD";

        public final static String COLUMN_NAME_EMAIL = "EMAIL";

        public final static String COLUMN_NAME_FIRSTNAME = "FIRSTNAME";

        public final static String COLUMN_NAME_LASTNAME = "LASTNAME";
    }
}
