/*
 * Copyright 2005-2007 WSO2, Inc. (http://wso2.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.solutions.identity.admin;

import org.wso2.solutions.identity.IdentityProviderException;
import org.wso2.solutions.identity.UserStore;
import org.wso2.solutions.identity.persistence.IPPersistenceManager;
import org.wso2.solutions.identity.persistence.dataobject.RealmConfigurationDO;
import org.wso2.solutions.identity.persistence.dataobject.RealmConfigurationPropertyDO;
import org.wso2.solutions.identity.persistence.dataobject.RealmDO;

import java.util.Iterator;
import java.util.Map;
import java.util.Set;

public class RealmConfigAdmin {

    public void createNewRealmConfiguration(String realmClassName,
            String configName, Map properties) throws IdentityProviderException {

        IPPersistenceManager db = IPPersistenceManager.getPersistanceManager();
        RealmDO realm = db.getRealm(realmClassName);

        RealmConfigurationDO realmConfig = new RealmConfigurationDO();
        realmConfig.setRealm(realm);
        realmConfig.setName(configName);

        db.create(realmConfig);
        Set keys = properties.keySet();
        for (Iterator iterator = keys.iterator(); iterator.hasNext();) {
            String prop = (String) iterator.next();
            RealmConfigurationPropertyDO propDo = new RealmConfigurationPropertyDO();
            propDo.setName(prop);
            propDo.setValue((String) properties.get(prop));
            propDo.setConfig(realmConfig);
            db.create(propDo);
        }
    }

    public void setDefaultRealmConfiguration(String configName)
            throws IdentityProviderException {
        IPPersistenceManager db = IPPersistenceManager.getPersistanceManager();
        RealmConfigurationDO effectiveConfig = db
                .getEffectiveRealmConfiguration();
        effectiveConfig.setEffective(false);
        db.update(effectiveConfig);
        RealmConfigurationDO config = db.getRealmConfiguration(configName);
        config.setEffective(true);
        db.update(config);
        UserStore.getInstance().changeRalm(configName);
        //Now reset claim mappings
        ClaimsAdmin claimsAdmin = new ClaimsAdmin();
        claimsAdmin.resetClaimMappings();
    }

}
