/*
 * Copyright 2005-2007 WSO2, Inc. (http://wso2.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.solutions.identity.admin;

import java.util.ArrayList;
import java.util.List;

import org.apache.axis2.AxisFault;
import org.wso2.solutions.identity.IdentityProviderConstants;
import org.wso2.solutions.identity.IdentityProviderException;
import org.wso2.solutions.identity.persistence.IPPersistenceManager;
import org.wso2.solutions.identity.persistence.dataobject.VerifierServiceIdpDO;
import org.wso2.wsas.admin.service.UserAdmin;
import org.wso2.wsas.admin.service.util.RoleData;
import org.wso2.wsas.admin.service.util.UserData;

public class TokenVerifierServiceAdmin {

    public VerifierServiceIdpDO[] getGlobalIDPs() throws AxisFault {
        VerifierServiceIdpDO[] idps = new VerifierServiceIdpDO[1];
        try {
            IPPersistenceManager manager = IPPersistenceManager
                    .getPersistanceManager();
            return manager.getAllVerifierServiceIdpDO();
        } catch (IdentityProviderException e) {
            AxisFault.makeFault(e);
        }
        return idps;
    }

    public VerifierServiceIdpDO getVerifierServiceIdpDO(Long longId) {
        VerifierServiceIdpDO idpDO = new VerifierServiceIdpDO();

        try {
            IPPersistenceManager manager = IPPersistenceManager
                    .getPersistanceManager();
            idpDO = (VerifierServiceIdpDO) manager.getDataObject(
                    VerifierServiceIdpDO.class.getName(), longId);
        } catch (IdentityProviderException e) {
            AxisFault.makeFault(e);
        }

        return idpDO;
    }

    public void addVerifierServiceIdpDO(VerifierServiceIdpDO idp)
            throws AxisFault {
        try {
            IPPersistenceManager manager = IPPersistenceManager
                    .getPersistanceManager();
            manager.create(idp);
        } catch (IdentityProviderException e) {
            AxisFault.makeFault(e);
        }
    }

    public void editVerifierServiceIdpDO(VerifierServiceIdpDO idp)
            throws AxisFault {
        try {
            IPPersistenceManager manager = IPPersistenceManager
                    .getPersistanceManager();
            manager.update(idp);
        } catch (IdentityProviderException e) {
            AxisFault.makeFault(e);
        }
    }

    public void deleteVerifierServiceIdpDO(Long longId) throws AxisFault {
        try {
            IPPersistenceManager manager = IPPersistenceManager
                    .getPersistanceManager();
            VerifierServiceIdpDO idpDO = (VerifierServiceIdpDO) manager
                    .getDataObject(VerifierServiceIdpDO.class.getName(), longId);
            manager.delete(idpDO);
        } catch (IdentityProviderException e) {
            AxisFault.makeFault(e);
        }

    }

    // ////////////////////////

    public String[] getRelyingPartyUsers() throws AxisFault {
        UserAdmin admin = new UserAdmin();
        UserData[] data = admin.getUserNames();

        List lst = new ArrayList();
        for (int i = 0; i < data.length; i++) {
            UserData temp = data[i];
            RoleData[] rdata = temp.getRoles();
            for (int j = 0; j < rdata.length; j++) {
                RoleData rtemp = rdata[j];
                String roleName = rtemp.getRole();
                if (roleName.equals(IdentityProviderConstants.RP_USER_ROLE)) {
                    lst.add(temp.getUserName());
                    break;
                }
            }
        }

        String[] names = (String[]) lst.toArray(new String[lst.size()]);
        return names;

    }

    public void addRelyingPartyUser(String username, String password) throws AxisFault {
        UserAdmin admin = new UserAdmin();
        admin.addUser(username, password,
                IdentityProviderConstants.RP_USER_ROLE, null);
    }

    public boolean editRelyingPartyUserPassword(String oldPassword, String username,
            String password) throws AxisFault {
        boolean successful = false;
        try {
            UserAdmin admin = new UserAdmin();
            successful = admin
                    .editUserPassword(oldPassword, username, password);

        } catch (Exception e) {
            AxisFault.makeFault(e);
        }
        return successful;
    }

    public void deleteRelyingPartyUser(String username) throws AxisFault {
        try {
            UserAdmin admin = new UserAdmin();
            admin.deleteUser(username);
        } catch (Exception e) {
            AxisFault.makeFault(e);
        }
    }

}
