/*
 * Copyright 2005-2007 WSO2, Inc. (http://wso2.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.solutions.identity.relyingparty.servletfilter;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;
import org.apache.axiom.om.impl.builder.StAXOMBuilder;

import javax.xml.namespace.QName;

import java.io.File;
import java.io.FileWriter;
import java.util.Hashtable;

public class RelyingPartyFilterConfiguration {

    public final static String KEYSTORE = "Keystore";

    public final static String STORE_PASS = "StorePass";

    public final static String KEY_ALIAS = "KeyAlias";

    public final static String KEY_PASS = "KeyPass";

    public final static String STORE_TYPE = "StoreType";

    public final static String CERT_ALIAS = "CertAlias";

    public final static String VERIFIER_URL = "VerifierService";

    public final static String SERVICE_KEY = "ServiceKey";

    public final static String TRUSTED_STS = "TrutedSTS";

    public final static String RP_CONFIG = "RPConfig";

    public final static String TRUST_STORE = "TrustStore";

    public final static String TRUST_STORE_FILE = "TrustKeystore";

    public final static String TRUST_STORE_PASS = "TrustStorePass";

    private String configFilePath;

    private String serviceKeystore;

    private String serviceStorePass;

    private String serviceStoreType;

    private String serviceKeyAlias;

    private String serviceKeyPass;

    private String stsKeystore;

    private String stsStorePass;

    private String stsStoreType;

    private String stsCertAlias;

    private String verifierURL;

    private String trustStoreFileName = null;

    private String trustStorePass = null;

    private boolean doCustomizeSSL = false;

    private static Hashtable configs = new Hashtable();

    public static RelyingPartyFilterConfiguration getInstance(
            String confFilePath) throws Exception {
        if (!configs.containsKey(confFilePath)) {
            RelyingPartyFilterConfiguration conf = new RelyingPartyFilterConfiguration(
                    confFilePath);
            configs.put(confFilePath, conf);
        }
        return (RelyingPartyFilterConfiguration) configs.get(confFilePath);
    }

    private RelyingPartyFilterConfiguration(String configFilePath)
            throws Exception {
        File configFile = new File(configFilePath);
        this.configFilePath = configFilePath;

        if (configFile.exists()) {

            StAXOMBuilder builder = new StAXOMBuilder(configFilePath);
            OMElement configElem = builder.getDocumentElement();

            // ServiceKey
            OMElement serviceKeyElem = configElem
                    .getFirstChildWithName(new QName(SERVICE_KEY));
            this.serviceKeystore = serviceKeyElem.getFirstChildWithName(
                    new QName(KEYSTORE)).getText().trim();
            this.serviceStoreType = serviceKeyElem.getFirstChildWithName(
                    new QName(STORE_TYPE)).getText().trim();
            this.serviceStorePass = serviceKeyElem.getFirstChildWithName(
                    new QName(STORE_PASS)).getText().trim();
            this.serviceKeyAlias = serviceKeyElem.getFirstChildWithName(
                    new QName(KEY_ALIAS)).getText().trim();
            this.serviceKeyPass = serviceKeyElem.getFirstChildWithName(
                    new QName(KEY_PASS)).getText().trim();

            OMElement verifyElem = configElem.getFirstChildWithName(new QName(
                    VERIFIER_URL));
            this.verifierURL = verifyElem.getText().trim();

            OMElement trustStoreElem = configElem
                    .getFirstChildWithName(new QName(TRUST_STORE));
            if (trustStoreElem != null) {
                doCustomizeSSL = true;
                this.trustStoreFileName = trustStoreElem.getFirstChildWithName(
                        new QName(TRUST_STORE_FILE)).getText().trim();
                this.trustStorePass = trustStoreElem.getFirstChildWithName(
                        new QName(TRUST_STORE_PASS)).getText().trim();
            }

        }
    }

    public void save() throws Exception {
        File configFile = new File(configFilePath);

        if (configFile.exists()) {
            configFile.delete();
        }

        configFile.createNewFile();
        OMFactory fac = OMAbstractFactory.getOMFactory();
        OMElement elem = fac.createOMElement(RP_CONFIG, null);

        OMElement serviceKeyElem = fac.createOMElement(new QName(SERVICE_KEY),
                elem);
        OMElement serviceKeystoreElem = fac.createOMElement(
                new QName(KEYSTORE), serviceKeyElem);
        serviceKeystoreElem.setText(this.serviceKeystore);
        OMElement serviceStoreTypeElem = fac.createOMElement(new QName(
                STORE_TYPE), serviceKeyElem);
        serviceStoreTypeElem.setText(this.serviceStoreType);
        OMElement serviceStorePassElem = fac.createOMElement(new QName(
                STORE_PASS), serviceKeyElem);
        serviceStorePassElem.setText(this.serviceStorePass);
        OMElement serviceKeyAliasElem = fac.createOMElement(
                new QName(KEY_ALIAS), serviceKeyElem);
        serviceKeyAliasElem.setText(this.serviceKeyAlias);
        OMElement serviceKeyPassElem = fac.createOMElement(new QName(KEY_PASS),
                serviceKeyElem);
        serviceKeyPassElem.setText(this.serviceKeyPass);

        OMElement trustedCertElem = fac.createOMElement(new QName(TRUSTED_STS),
                elem);
        OMElement stsKeystoreElem = fac.createOMElement(new QName(KEYSTORE),
                trustedCertElem);
        stsKeystoreElem.setText(this.stsKeystore);
        OMElement stsStoreTypeElem = fac.createOMElement(new QName(STORE_TYPE),
                trustedCertElem);
        stsStoreTypeElem.setText(this.stsStoreType);
        OMElement stsStorePassElem = fac.createOMElement(new QName(STORE_PASS),
                trustedCertElem);
        stsStorePassElem.setText(this.stsStorePass);
        OMElement stsKeyAliasElem = fac.createOMElement(new QName(CERT_ALIAS),
                trustedCertElem);
        stsKeyAliasElem.setText(this.stsCertAlias);
        OMElement verifierServiceElem = fac.createOMElement(new QName(
                VERIFIER_URL), elem);
        verifierServiceElem.setText(this.verifierURL);

        String xml = elem.toString();

        System.out.println("service store : " + serviceKeystore);
        System.out.println("Saving : " + xml);

        FileWriter writer = new FileWriter(configFile);
        writer.write(xml);
        writer.flush();
        writer.close();
    }

    public String getConfigFilePath() {
        return configFilePath;
    }

    public void setConfigFilePath(String configFilePath) {
        this.configFilePath = configFilePath;
    }

    public String getServiceKeyAlias() {
        return serviceKeyAlias;
    }

    public void setServiceKeyAlias(String serviceKeyAlias) {
        this.serviceKeyAlias = serviceKeyAlias;
    }

    public String getServiceKeyPass() {
        return serviceKeyPass;
    }

    public void setServiceKeyPass(String serviceKeyPass) {
        this.serviceKeyPass = serviceKeyPass;
    }

    public String getServiceKeystore() {
        return serviceKeystore;
    }

    public void setServiceKeystore(String serviceKeystore) {
        this.serviceKeystore = serviceKeystore;
    }

    public String getServiceStorePass() {
        return serviceStorePass;
    }

    public void setServiceStorePass(String serviceStorePass) {
        this.serviceStorePass = serviceStorePass;
    }

    public String getServiceStoreType() {
        return serviceStoreType;
    }

    public void setServiceStoreType(String serviceStoreType) {
        this.serviceStoreType = serviceStoreType;
    }

    public String getStsCertAlias() {
        return stsCertAlias;
    }

    public void setStsCertAlias(String stsCertAlias) {
        this.stsCertAlias = stsCertAlias;
    }

    public String getStsKeystore() {
        return stsKeystore;
    }

    public void setStsKeystore(String stsKeystore) {
        this.stsKeystore = stsKeystore;
    }

    public String getStsStorePass() {
        return stsStorePass;
    }

    public void setStsStorePass(String stsStorePass) {
        this.stsStorePass = stsStorePass;
    }

    public String getStsStoreType() {
        return stsStoreType;
    }

    public void setStsStoreType(String stsStoreType) {
        this.stsStoreType = stsStoreType;
    }

    public String getVerifierURL() {
        return verifierURL;
    }

    public void setVerifierURL(String verifierURL) {
        this.verifierURL = verifierURL;
    }

    public boolean getDoCustomizeSSL() {
        return doCustomizeSSL;
    }

    public String getTrustStoreFileName() {
        return trustStoreFileName;
    }

    public String getTrustStorePass() {
        return trustStorePass;
    }

    public void setDoCustomizeSSL(boolean doCustomizeSSL) {
        this.doCustomizeSSL = doCustomizeSSL;
    }

    public void setTrustStoreFileName(String trustStoreFileName) {
        this.trustStoreFileName = trustStoreFileName;
    }

    public void setTrustStorePass(String trustStorePass) {
        this.trustStorePass = trustStorePass;
    }

}
